@@ -39,9 +39,9 @@
 
 #define HOME_DIR g_get_home_dir()
 
-#define IP_COMMAND "/sbin/ifconfig | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}' | grep -v \"127.0.0.1\""
-//#define INTERFACE_COMMAND "/sbin/ifconfig -a| tr -s ' ' | sed 's/ /,/' | tr '\n' \| | sed 's/||/\n/' | grep \"inet addr\" | grep -v \"127.0.0.1\""
-#define INTERFACE_COMMAND "/sbin/ifconfig | tr '\\n' \\~ | sed 's/\\~\\~/\\n/g\' | grep \"inet addr\" | grep -v \"lo\" | awk '{print $1}'"
+#define IFCONFIG "/sbin/ifconfig "
+#define IP_COMMAND " | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}'"
+#define INTERFACE_COMMAND "/sbin/route -n | grep \"UG\" | awk '{print $8}'"
 
 #define _(String) dgettext("hildon-libs", String)
 
@@ -59,7 +59,7 @@ struct _PersonalIpAddressPrivate
 	GtkWidget *ipContent;
 	GtkWidget *interfaceContent;
 	
-	gint refresh;
+	gboolean connectOnPress;
 	gboolean isPressed;
 	
 	ConIcConnection *connection;
@@ -71,7 +71,7 @@ HD_DEFINE_PLUGIN_MODULE (PersonalIpAddress, personal_ip_address, HD_TYPE_HOME_PL
 
 //gboolean personal_ip_address_update_content (PersonalIpAddress *self);
 
-/*void personal_ip_address_read_settings ( PersonalIpAddress *self )
+void personal_ip_address_read_settings ( PersonalIpAddress *self )
 {
 	//g_warning("personal_ip_address_read_settings");	
     gchar *filename;
@@ -85,28 +85,14 @@ HD_DEFINE_PLUGIN_MODULE (PersonalIpAddress, personal_ip_address, HD_TYPE_HOME_PL
     if (fileExists) {
         GError *error=NULL;
 
-        self->priv->refresh = g_key_file_get_integer (keyFile, "config", "refresh", &error);
+        self->priv->connectOnPress = g_key_file_get_gboolean (keyFile, "config", "connectOnPress", &error);
         if (error) {
-            self->priv->refresh = 5;
+            self->priv->connectOnPress = FALSE;
             g_error_free (error);
             error = NULL;
         }
-		self->priv->binaryPrefix = g_key_file_get_boolean (keyFile, "config", "binaryPrefix", &error);
-		if (error) {
-			self->priv->binaryPrefix = FALSE;
-			g_error_free (error);
-			error = NULL;
-		}
-		self->priv->showResetDate = g_key_file_get_boolean (keyFile, "config", "showResetDate", &error);
-		if (error) {
-			self->priv->showResetDate = FALSE;
-			g_error_free (error);
-			error = NULL;
-		}
     } else {
-        self->priv->refresh = 5;
-		self->priv->binaryPrefix = FALSE;
-		self->priv->showResetDate = FALSE;
+        self->priv->connectOnPress = FALSE;
     }
 
     g_key_file_free (keyFile);
@@ -127,9 +113,7 @@ void personal_ip_address_write_settings (PersonalIpAddress *self)
 	
 	keyFile = g_key_file_new();
 		
-	g_key_file_set_integer (keyFile, "config", "refresh", self->priv->refresh);
-	g_key_file_set_boolean (keyFile, "config", "binaryPrefix", self->priv->binaryPrefix);
-	g_key_file_set_boolean (keyFile, "config", "showResetDate", self->priv->showResetDate);
+	g_key_file_set_integer (keyFile, "config", "connectOnPress", self->priv->connectOnPress);
 	
 	filename = g_strconcat (HOME_DIR, "/.personal_ip_address", NULL);
 	fileData = g_key_file_to_data (keyFile, &size, NULL);
@@ -139,30 +123,36 @@ void personal_ip_address_write_settings (PersonalIpAddress *self)
 	g_key_file_free (keyFile);
 	g_free (fileData);
 	g_free (filename);
-}*/
+}
 
 void personal_ip_address_button_press (GtkWidget *widget, GdkEventButton *event, PersonalIpAddress *self)
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
-	self->priv->isPressed = TRUE;
-	gtk_widget_queue_draw (GTK_WIDGET (self));
+	if (self->priv->connectOnPress) {
+		self->priv->isPressed = TRUE;
+		gtk_widget_queue_draw (GTK_WIDGET (self));
+	}
 }
 
 void personal_ip_address_button_release (GtkWidget *widget, GdkEventButton *event, PersonalIpAddress *self)
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
-	self->priv->isPressed = FALSE;
+	if (self->priv->connectOnPress) {
+		self->priv->isPressed = FALSE;
 	
-	con_ic_connection_connect (self->priv->connection, CON_IC_CONNECT_FLAG_NONE);
+		con_ic_connection_connect (self->priv->connection, CON_IC_CONNECT_FLAG_NONE);
 	
-	gtk_widget_queue_draw (GTK_WIDGET (self));
+		gtk_widget_queue_draw (GTK_WIDGET (self));
+	}
 }
 
 void personal_ip_address_leave_event (GtkWidget *widget, GdkEventCrossing *event, PersonalIpAddress *self)
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
-	self->priv->isPressed = FALSE;
-	gtk_widget_queue_draw (GTK_WIDGET (self));
+	if (self->priv->connectOnPress) {
+		self->priv->isPressed = FALSE;
+		gtk_widget_queue_draw (GTK_WIDGET (self));
+	}
 }
 
 void personal_ip_address_content_create (PersonalIpAddress *self)
@@ -173,36 +163,6 @@ void personal_ip_address_content_create (PersonalIpAddress *self)
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
-	/*GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
-    self->priv->titleLabel = gtk_label_new ("IP Address");
-	hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
-	GtkWidget *titleBox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (titleBox), 0);
-	gtk_box_pack_start (GTK_BOX (titleBox), image, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (titleBox), self->priv->titleLabel, TRUE, TRUE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 1);
-	gtk_misc_set_padding (GTK_MISC (image), 2, 0);
-	gtk_misc_set_alignment (GTK_MISC (self->priv->titleLabel), 0, 0.8);
-	
-	self->priv->ipLabel = gtk_label_new ("IP");
-	gtk_size_group_add_widget (group, self->priv->ipLabel);
-	self->priv->ipContent = gtk_label_new ("127.0.0.1");
-	GtkWidget *ipBox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (ipBox), self->priv->ipLabel, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (ipBox), self->priv->ipContent, TRUE, TRUE, 0);
-	hildon_helper_set_logical_font (self->priv->ipLabel, "SmallSystemFont");
-	hildon_helper_set_logical_font (self->priv->ipContent, "SmallSystemFont");
-	hildon_helper_set_logical_color (self->priv->ipContent, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
-	gtk_misc_set_alignment (GTK_MISC (self->priv->ipLabel), 0, 0.5);
-	gtk_misc_set_padding (GTK_MISC (self->priv->ipLabel), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
-	gtk_misc_set_alignment (GTK_MISC (self->priv->ipContent), 1, 0.5);
-	gtk_misc_set_padding (GTK_MISC (self->priv->ipContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
-	
-	gtk_box_pack_start (GTK_BOX (self->priv->contents), titleBox, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (self->priv->contents), ipBox, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);*/
-	
-	//GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
 	self->priv->ipLabel = gtk_label_new ("IP");
 	GtkWidget *box = gtk_hbox_new (FALSE, 0);
 	self->priv->interfaceContent = gtk_label_new ("");
@@ -233,22 +193,21 @@ gboolean personal_ip_address_update_content (PersonalIpAddress *self)
 	//g_warning ("personal_ip_address_update_content");
 	FILE *fp;
 	gchar line[256];
+	gchar *interface;
 	gboolean found = FALSE;
 
 	fp = popen (INTERFACE_COMMAND, "r");
-	//g_warning ("/sbin/ifconfig | tr '\\n' \\~ | sed 's/\\~\\~/\\n/g\' | grep \"inet addr\" | grep -v \"lo\" | awk '{FS=\",\"} {print $1}'");
-
+	
 	while (fgets (line, sizeof line, fp)) {
-		gchar *gline = g_strdup_printf ("%s", line);
-		gtk_label_set_text (GTK_LABEL (self->priv->interfaceContent), g_strstrip (gline));
+		interface = g_strstrip (g_strdup_printf ("%s", line));
+		gtk_label_set_text (GTK_LABEL (self->priv->interfaceContent), interface);
 		found = TRUE;
-		g_free (gline);
 	}
 	pclose (fp);
 	
 	if (found) {
 		found = FALSE;
-		fp = popen (IP_COMMAND, "r");
+		fp = popen (g_strconcat (IFCONFIG, interface, IP_COMMAND, NULL) , "r");
 		
 		while (fgets (line, sizeof line, fp)) {
 			gchar *gline = g_strdup_printf ("%s", line);
@@ -263,6 +222,7 @@ gboolean personal_ip_address_update_content (PersonalIpAddress *self)
 		gtk_label_set_text (GTK_LABEL (self->priv->interfaceContent), "");
 		gtk_label_set_text (GTK_LABEL (self->priv->ipContent), "(no IP found)");
 	}
+	g_free (interface);
 }
 
 gboolean personal_ip_address_connection_changed (ConIcConnection *connection, ConIcConnectionEvent *event, PersonalIpAddress *self)
@@ -272,69 +232,29 @@ gboolean personal_ip_address_connection_changed (ConIcConnection *connection, Co
 	return TRUE;
 }
 
-/*void personal_ip_address_settings (HDHomePluginItem *hitem, PersonalIpAddress *self)
+void personal_ip_address_settings (HDHomePluginItem *hitem, PersonalIpAddress *self)
 {
 	//g_warning ("personal_ip_address_settings");
-	GtkWidget *dialog = gtk_dialog_new_with_buttons ("Personal Dataplan Monitor Settings",
-        NULL, 0,
-        _("wdgt_bd_save"), GTK_RESPONSE_ACCEPT, NULL);
+	GtkWidget *dialog = gtk_dialog_new_with_buttons ("Personal IP Address Settings",
+        NULL, 0, _("wdgt_bd_save"), GTK_RESPONSE_ACCEPT, NULL);
     GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 	
-	GtkWidget *selector = hildon_touch_selector_new_text ();
-	
-	int i;
-	for (i=0; i<=60; i++) {
-		gchar *text = g_strdup_printf ("%d seconds(s)", i);
-		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), text);
-		g_free (text);
-	}
-	self->priv->refresh;
-	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->refresh);
-	
-	GtkWidget *refreshButton = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
-	hildon_button_set_title (HILDON_BUTTON (refreshButton), "Update every");
-	hildon_button_add_title_size_group (HILDON_BUTTON (refreshButton), group);
-	hildon_button_set_alignment (HILDON_BUTTON (refreshButton), 0, 0.5, 0, 0);
-
-	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (refreshButton),
-                                     HILDON_TOUCH_SELECTOR (selector));
-	gtk_container_add (GTK_CONTAINER (content_area), refreshButton);
-	
-	GtkWidget *refreshLabel = gtk_label_new ("'0' will refresh only when switching to the desktop");
-	gtk_label_set_markup (GTK_LABEL (refreshLabel), "<small>'0' will refresh only when switching to the desktop</small>");
-	gtk_container_add (GTK_CONTAINER (content_area), refreshLabel);
-	
-	GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
-	GtkWidget *binaryPrefix = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, NULL);
-	gtk_button_set_label (GTK_BUTTON (binaryPrefix), "Binary prefixes (KiB)");
-	GtkWidget *siPrefix = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, gtk_radio_button_get_group (GTK_RADIO_BUTTON (binaryPrefix)));
-	gtk_button_set_label (GTK_BUTTON (siPrefix), "SI prefixes (kB)");
-	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (binaryPrefix), FALSE);
-	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (siPrefix), FALSE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (binaryPrefix), self->priv->binaryPrefix);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (siPrefix), !self->priv->binaryPrefix);
-	gtk_container_add (GTK_CONTAINER (hbox), binaryPrefix);
-	gtk_container_add (GTK_CONTAINER (hbox), siPrefix);
-	gtk_container_add (GTK_CONTAINER (content_area), hbox);
-	
-	GtkWidget *showResetDate = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (showResetDate), "Display the last reset date");
-	gtk_container_add (GTK_CONTAINER (content_area), showResetDate);
-	hildon_check_button_set_active (HILDON_CHECK_BUTTON (showResetDate), self->priv->showResetDate);
+	GtkWidget *connectOnPress = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (connectOnPress), "Connect to network when pressed");
+	gtk_container_add (GTK_CONTAINER (content_area), connectOnPress);
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (connectOnPress), self->priv->connectOnPress);
 	
 	gtk_widget_show_all (dialog);
 	
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
-		self->priv->refresh = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
-		self->priv->binaryPrefix = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (binaryPrefix));
-		self->priv->showResetDate = hildon_check_button_get_active (HILDON_CHECK_BUTTON (showResetDate));
+		self->priv->connectOnPress = hildon_check_button_get_active (HILDON_CHECK_BUTTON (connectOnPress));
 		
 		personal_ip_address_write_settings (self);
 		personal_ip_address_update_content (self);
 	}
 	gtk_widget_destroy (dialog);
-}*/
+}
 
 static void personal_ip_address_check_desktop (GObject *gobject, GParamSpec *pspec, PersonalIpAddress *self)
 {
@@ -468,8 +388,8 @@ static void personal_ip_address_init (PersonalIpAddress *self)
 	g_signal_connect (self->priv->connection, "connection-event", G_CALLBACK (personal_ip_address_connection_changed), self);
 	g_object_set (self->priv->connection, "automatic-connection-events", TRUE);
 	
-	//hd_home_plugin_item_set_settings (&self->parent, TRUE);
-	//g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_ip_address_settings), self);
+	hd_home_plugin_item_set_settings (&self->parent, TRUE);
+	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_ip_address_settings), self);
 
 	gtk_window_set_default_size (GTK_WINDOW (self), 315, 40);
 	
@@ -484,7 +404,7 @@ static void personal_ip_address_init (PersonalIpAddress *self)
 	hints.max_height = 40;
 	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 	
-	//personal_ip_address_read_settings (self);
+	personal_ip_address_read_settings (self);
 	
 	personal_ip_address_content_create (self);
 	personal_ip_address_update_content (self);
